@@ -9,9 +9,8 @@ from typing import Sequence, Union, List, Tuple
 
 class WhereExec:
 
-    def __init__(self, table, executor, **where_condition):
-        self.table = table
-        self.executor = executor
+    def __init__(self, table_name, **where_condition):
+        self.table = table_name
         self.where_condition = where_condition
 
     def get(self, column: str):
@@ -23,7 +22,7 @@ class WhereExec:
         """
         where, args, _ = get_where_arg_limit(**self.where_condition)
         sql = get_select_sql(self.table, where, LIMIT_1, column)
-        return self.executor.do_get(sql, *args, LIMIT_1)
+        return exec.do_get(sql, *args, LIMIT_1)
 
     def count(self):
         """
@@ -42,7 +41,7 @@ class WhereExec:
                 args = [*args, limit]
             else:
                 args = [*args, *limit]
-        return self.executor.do_select(sql, *args)
+        return exec.do_select(sql, *args)
 
     def select_one(self, *columns):
         """
@@ -50,7 +49,7 @@ class WhereExec:
         """
         where, args, _ = get_where_arg_limit(**self.where_condition)
         sql = get_select_sql(self.table, where, LIMIT_1, *columns)
-        return self.executor.do_select_one(sql, *args, LIMIT_1)
+        return exec.do_select_one(sql, *args, LIMIT_1)
 
     def query(self, *columns):
         """
@@ -63,7 +62,7 @@ class WhereExec:
                 args = [*args, limit]
             else:
                 args = [*args, *limit]
-        return self.executor.do_query(sql, *args)
+        return exec.do_query(sql, *args)
 
     def query_one(self, *columns):
         """
@@ -71,7 +70,7 @@ class WhereExec:
         """
         where, args, _ = get_where_arg_limit(**self.where_condition)
         sql = get_select_sql(self.table, where, LIMIT_1, *columns)
-        return self.executor.do_query_one(sql, *args, LIMIT_1)
+        return exec.do_query_one(sql, *args, LIMIT_1)
 
     def delete(self):
         """
@@ -79,7 +78,7 @@ class WhereExec:
         """
         where, args, _ = get_where_arg_limit(**self.where_condition)
         sql = 'DELETE FROM %s %s' % (self.table, where)
-        return self.executor.do_execute(sql, *args)
+        return exec.do_execute(sql, *args)
 
     def update(self, **kwargs):
         """
@@ -90,7 +89,7 @@ class WhereExec:
         args = [*update_args, *args]
         update_cols = ', '.join(['{} = ?'.format(col) for col in update_cols])
         sql = 'UPDATE {} SET {} {}'.format(self.table, update_cols, where)
-        return self.executor.do_execute(sql, *args)
+        return exec.do_execute(sql, *args)
 
     def load(self, *columns) -> Loader:
         """
@@ -103,14 +102,13 @@ class WhereExec:
                 args = [*args, limit]
             else:
                 args = [*args, *limit]
-        return self.executor.do_load(sql, *args)
+        return exec.do_load(sql, *args)
 
 
 class TableExec:
 
-    def __init__(self, table, executor):
-        self.table = table
-        self.executor = executor
+    def __init__(self, table_name):
+        self.table = table_name
 
     def insert(self, **kwargs):
         """
@@ -119,7 +117,7 @@ class TableExec:
         :param kwargs: {name='张三', age=20}
         return: Effect rowcount
         """
-        return self.executor.insert(self.table, **kwargs)
+        return exec.insert(self.table, **kwargs)
 
     def save(self, select_key: str, **kwargs):
         """
@@ -129,7 +127,7 @@ class TableExec:
         :param kwargs:
         :return: Primary key
         """
-        return self.executor.save(select_key, self.table, **kwargs)
+        return exec.save(select_key, self.table, **kwargs)
 
     def get(self, column: str):
         """
@@ -139,7 +137,7 @@ class TableExec:
         sqlexec.table('user').get('count(1)')
         """
         sql = get_select_sql(self.table, '', LIMIT_1, column)
-        return self.executor.do_get(sql, LIMIT_1)
+        return exec.do_get(sql, LIMIT_1)
 
     def count(self):
         """
@@ -152,83 +150,83 @@ class TableExec:
         sqlexec.table('user').select('name', 'age')
         """
         sql = get_select_sql(self.table, '', 0, *columns)
-        return self.executor.do_select(sql)
+        return exec.do_select(sql)
 
     def select_one(self, *columns):
         """
         sqlexec.table('user').select_one('name', 'age')
         """
         sql = get_select_sql(self.table, '', LIMIT_1, *columns)
-        return self.executor.do_select_one(sql, LIMIT_1)
+        return exec.do_select_one(sql, LIMIT_1)
 
     def query(self, *columns):
         """
         sqlexec.table('user').query('name', 'age')
         """
         sql = get_select_sql(self.table, '', 0, *columns)
-        return self.executor.do_query(sql)
+        return exec.do_query(sql)
 
     def query_one(self, *columns):
         """
         sqlexec.table('user').query_one('name', 'age')
         """
         sql = get_select_sql(self.table, '', LIMIT_1, *columns)
-        return self.executor.do_query_one(sql, LIMIT_1)
+        return exec.do_query_one(sql, LIMIT_1)
 
     def batch_insert(self, *args):
         """
         Execute sql return effect rowcount
         :param args: [{'name': '张三', 'age': 20}, {'name': '李四', 'age': 28}]
         """
-        return self.executor.batch_insert(self.table, *args)
+        return exec.batch_insert(self.table, *args)
 
     def load(self, *columns) -> Loader:
         """
         sqlexec.table('user').load('name', 'age')
         """
         sql = get_select_sql(self.table, '', 0, *columns)
-        return self.executor.do_load(sql)
+        return exec.do_load(sql)
 
     def insert_from_csv(self, file_name: str, delimiter=',', header=True, columns: Tuple[str] = None, encoding='utf-8'):
         """
         sqlexec.table('user').insert_from_csv('test.csv')
         """
-        return self.executor.insert_from_csv(file_name, self.table, delimiter, header, columns, encoding=encoding)
+        return exec.insert_from_csv(file_name, self.table, delimiter, header, columns, encoding=encoding)
 
     def insert_from_df(self, df, columns: Tuple[str] = None):
         """
         sqlexec.table('user').insert_from_df(df)
         """
-        return self.executor.insert_from_df(df, self.table, columns)
+        return exec.insert_from_df(df, self.table, columns)
 
     def insert_from_json(self, file_name: str, encoding='utf-8'):
         """
         sqlexec.table('user').insert_from_json('test.csv')
         """
-        return self.executor.insert_from_json(file_name, self.table, encoding=encoding)
+        return exec.insert_from_json(file_name, self.table, encoding=encoding)
 
     def where(self, **kwargs) -> WhereExec:
-        return WhereExec(self.table, self.executor, **kwargs)
+        return WhereExec(self.table, **kwargs)
 
 
-def table(table: str) -> TableExec:
-    table = table.strip()
-    assert table, "Parameter 'table' must not be none"
-    return TableExec(table, exec)
+def table(table_name: str) -> TableExec:
+    table_name = table_name.strip()
+    assert table_name, "Parameter 'table' must not be none"
+    return TableExec(table_name)
 
 
-def get_select_sql(table: str, where: str, limit: Union[int, Tuple[int], List[int]], *columns):
+def get_select_sql(table_name: str, where: str, limit: Union[int, Tuple[int], List[int]], *columns):
     columns = ','.join([col if '(' in col else '{}'.format(col) for col in columns]) if columns else '*'
 
     if limit:
         if isinstance(limit, int):
-            return 'SELECT {} FROM {} {} LIMIT ?'.format(columns, table, where)
+            return 'SELECT {} FROM {} {} LIMIT ?'.format(columns, table_name, where)
         elif (isinstance(limit, Tuple) or isinstance(limit, List)) and len(limit) == 2:
-            return 'SELECT {} FROM {} {} LIMIT ? OFFSET ?'.format(columns, table, where)
+            return 'SELECT {} FROM {} {} LIMIT ? OFFSET ?'.format(columns, table_name, where)
         else:
             raise ValueError("The type of the parameter 'limit' must be 'int' or tuple, list, and it length is 2.")
     else:
-        return 'SELECT {} FROM {} {}'.format(columns, table, where)
+        return 'SELECT {} FROM {} {}'.format(columns, table_name, where)
 
 
 def get_condition_arg(k: str, v: object):
